/*
    SPDX-FileCopyrightText: 2015 Daniel Vrátil <dvratil@redhat.com>

    SPDX-License-Identifier: LGPL-2.0-or-later
*/

#include "shared/icalresource.h"

AKONADI_RESOURCE_CORE_MAIN(ICalResource)
